@@ -54,9 +54,6 @@ class NodeConnector(QObject):
         self._ws_tasks = {"block": None, "peer": None}
         self._connected = {"block": False, "peer": False}
         self._user_parameters = user_parameters
-        if not session:
-            session = aiohttp.ClientSession()
-        self.session = session
         self._raw_logger = logging.getLogger("sakia")
         self._logger = NodeConnectorLoggerAdapter(
             self._raw_logger, {"pubkey": self.node.pubkey}
@@ -80,10 +77,11 @@ class NodeConnector(QObject):
         :rtype: sakia.core.net.Node
         """
         endpoint = get_bma_endpoint_from_server_address(address, port, secured)
-        # Create Client from endpoint string in Duniter format
-        client = Client(endpoint, proxy=user_parameters.proxy())
 
-        peer_data = client(bma.network.peering)
+        async with aiohttp.ClientSession() as session:
+            # Create Client from endpoint string in Duniter format
+            client = Client(endpoint, session, proxy=user_parameters.proxy())
+            peer_data = client(bma.network.peering)
 
         peer = Peer.from_signed_raw(
             "{0}{1}\n".format(peer_data["raw"], peer_data["signature"])
@@ -130,41 +128,35 @@ class NodeConnector(QObject):
         return cls(node, user_parameters, session=None)
 
     async def safe_request(self, endpoint, request, proxy, req_args={}):
-        try:
-            client = Client(endpoint, self.session, proxy)
-            data = await client(request, **req_args)
-            return data
-        except errors.DuniterError as e:
-            if e.ucode == 1006:
-                self._logger.debug("{0}".format(str(e)))
-            else:
-                raise
-        except (
-            ClientError,
-            gaierror,
-            TimeoutError,
-            ConnectionRefusedError,
-            ValueError,
-        ) as e:
-            self._logger.debug("{:}:{:}".format(str(e.__class__.__name__), str(e)))
-            self.handle_failure()
-        except jsonschema.ValidationError as e:
-            self._logger.debug("{:}:{:}".format(str(e.__class__.__name__), str(e)))
-            self.handle_failure(weight=3)
-        except RuntimeError:
-            if self.session.closed:
-                pass
-            else:
-                raise
-        except AttributeError as e:
-            if ("feed_appdata", "do_handshake") in str(e):
-                self._logger.debug(str(e))
-            else:
-                raise
-
-    async def init_session(self):
-        if not self.session:
-            self.session = aiohttp.ClientSession()
+        async with aiohttp.ClientSession() as session:
+            try:
+                client = Client(endpoint, session, proxy)
+                data = await client(request, **req_args)
+                return data
+            except errors.DuniterError as e:
+                if e.ucode == 1006:
+                    self._logger.debug("{0}".format(str(e)))
+                else:
+                    raise
+            except (
+                ClientError,
+                gaierror,
+                TimeoutError,
+                ConnectionRefusedError,
+                ValueError,
+            ) as e:
+                self._logger.debug("{:}:{:}".format(str(e.__class__.__name__), str(e)))
+                self.handle_failure()
+            except jsonschema.ValidationError as e:
+                self._logger.debug("{:}:{:}".format(str(e.__class__.__name__), str(e)))
+                self.handle_failure(weight=3)
+            except RuntimeError as e:
+                self._logger.error(str(e))
+            except AttributeError as e:
+                if "feed_appdata" in str(e) or "do_handshake" in str(e):
+                    self._logger.debug(str(e))
+                else:
+                    raise
 
     async def close_ws(self):
         for ws in self._ws_tasks.values():
@@ -179,7 +171,6 @@ class NodeConnector(QObject):
             else:
                 closed = True
             await asyncio.sleep(0)
-        await self.session.close()
         await asyncio.sleep(0)
 
     def refresh(self, manual=False):
@@ -205,61 +196,58 @@ class NodeConnector(QObject):
         """
         for endpoint in [e for e in self.node.endpoints if isinstance(e, BMAEndpoint)]:
             if not self._connected["block"]:
-                try:
-                    client = Client(
-                        endpoint, self.session, self._user_parameters.proxy()
-                    )
+                async with aiohttp.ClientSession() as session:
+                    try:
+                        client = Client(
+                            endpoint, session, self._user_parameters.proxy()
+                        )
 
-                    # Create Web Socket connection on block path (async method)
-                    ws = await client(bma.ws.block)  # Type: WSConnection
-                    self._connected["block"] = True
-                    self._logger.debug("Connected successfully to block ws")
+                        # Create Web Socket connection on block path (async method)
+                        ws = await client(bma.ws.block)  # Type: WSConnection
+                        self._connected["block"] = True
+                        self._logger.debug("Connected successfully to block ws")
 
-                    loop = True
-                    # Iterate on each message received...
-                    while loop:
-                        # Wait and capture next message
-                        try:
-                            block_data = await ws.receive_json()
-                            jsonschema.validate(block_data, bma.ws.WS_BLOCK_SCHEMA)
-                            self._logger.debug("Received a block")
-                            self.block_found.emit(
-                                BlockUID(block_data["number"], block_data["hash"])
-                            )
-                        except TypeError as exception:
-                            self._logger.debug(exception)
-                            self.handle_failure()
-                            break
+                        loop = True
+                        # Iterate on each message received...
+                        while loop:
+                            # Wait and capture next message
+                            try:
+                                block_data = await ws.receive_json()
+                                jsonschema.validate(block_data, bma.ws.WS_BLOCK_SCHEMA)
+                                self._logger.debug("Received a block")
+                                self.block_found.emit(
+                                    BlockUID(block_data["number"], block_data["hash"])
+                                )
+                            except TypeError as exception:
+                                self._logger.debug(exception)
+                                self.handle_failure()
+                                break
 
-                    # Close session
-                    await client.close()
-
-                except (aiohttp.WSServerHandshakeError, ValueError) as e:
-                    self._logger.debug(
-                        "Websocket block {0}: {1}".format(type(e).__name__, str(e))
-                    )
-                    self.handle_failure()
-                except (ClientError, gaierror, TimeoutError) as e:
-                    self._logger.debug("{0}: {1}".format(str(e), self.node.pubkey[:5]))
-                    self.handle_failure()
-                except jsonschema.ValidationError as e:
-                    self._logger.debug(
-                        "{:}:{:}".format(str(e.__class__.__name__), str(e))
-                    )
-                    self.handle_failure(weight=3)
-                except RuntimeError:
-                    if self.session.closed:
-                        pass
-                    else:
-                        raise
-                except AttributeError as e:
-                    if ("feed_appdata", "do_handshake") in str(e):
-                        self._logger.debug(str(e))
-                    else:
-                        raise
-                finally:
-                    self._connected["block"] = False
-                    self._ws_tasks["block"] = None
+                    except (aiohttp.WSServerHandshakeError, ValueError) as e:
+                        self._logger.debug(
+                            "Websocket block {0}: {1}".format(type(e).__name__, str(e))
+                        )
+                        self.handle_failure()
+                    except (ClientError, gaierror, TimeoutError) as e:
+                        self._logger.debug(
+                            "{0}: {1}".format(str(e), self.node.pubkey[:5])
+                        )
+                        self.handle_failure()
+                    except jsonschema.ValidationError as e:
+                        self._logger.debug(
+                            "{:}:{:}".format(str(e.__class__.__name__), str(e))
+                        )
+                        self.handle_failure(weight=3)
+                    except RuntimeError as e:
+                        self._logger.error(str(e))
+                    except AttributeError as e:
+                        if "feed_appdata" in str(e) or "do_handshake" in str(e):
+                            self._logger.debug(str(e))
+                        else:
+                            raise
+                    finally:
+                        self._connected["block"] = False
+                        self._ws_tasks["block"] = None
 
     async def connect_peers(self):
         """
@@ -268,65 +256,64 @@ class NodeConnector(QObject):
         """
         for endpoint in [e for e in self.node.endpoints if isinstance(e, BMAEndpoint)]:
             if not self._connected["peer"]:
-                try:
-                    client = Client(
-                        endpoint, self.session, self._user_parameters.proxy()
-                    )
+                async with aiohttp.ClientSession() as session:
+                    try:
+                        client = Client(
+                            endpoint, session, self._user_parameters.proxy()
+                        )
 
-                    # Create Web Socket connection on peer path (async method)
-                    ws = await client(bma.ws.peer)  # Type: WSConnection
-                    self._connected["peer"] = True
-                    self._logger.debug("Connected successfully to peer ws")
+                        # Create Web Socket connection on peer path (async method)
+                        ws = await client(bma.ws.peer)  # Type: WSConnection
+                        self._connected["peer"] = True
+                        self._logger.debug("Connected successfully to peer ws")
 
-                    loop = True
-                    # Iterate on each message received...
-                    while loop:
-                        try:
-                            # Wait and capture next message
-                            peer_data = await ws.receive_json()
-                            jsonschema.validate(peer_data, bma.ws.WS_PEER_SCHEMA)
-                            self._logger.debug("Received a peer")
-                            self.refresh_peer_data(peer_data)
-                        except TypeError as exception:
-                            self._logger.debug(exception)
-                            break
+                        loop = True
+                        # Iterate on each message received...
+                        while loop:
+                            try:
+                                # Wait and capture next message
+                                peer_data = await ws.receive_json()
+                                jsonschema.validate(peer_data, bma.ws.WS_PEER_SCHEMA)
+                                self._logger.debug("Received a peer")
+                                self.refresh_peer_data(peer_data)
+                            except TypeError as exception:
+                                self._logger.debug(exception)
+                                break
 
-                    # Close session
-                    await client.close()
+                        # Close session
+                        await client.close()
 
-                except (aiohttp.WSServerHandshakeError, ValueError) as e:
-                    self._logger.debug(
-                        "Websocket peer {0}: {1}".format(type(e).__name__, str(e))
-                    )
-                    await self.request_peers()
-                except (ClientError, gaierror, TimeoutError) as e:
-                    self._logger.debug(
-                        "{:}:{:}".format(str(e.__class__.__name__), str(e))
-                    )
-                    self.handle_failure()
-                except jsonschema.ValidationError as e:
-                    self._logger.debug(
-                        "{:}:{:}".format(str(e.__class__.__name__), str(e))
-                    )
-                    self.handle_failure(weight=3)
-                except RuntimeError:
-                    if self.session.closed:
-                        pass
-                    else:
-                        raise
-                except AttributeError as e:
-                    if ("feed_appdata", "do_handshake") in str(e):
-                        self._logger.debug(str(e))
-                    else:
-                        raise
-                finally:
-                    self._connected["peer"] = False
-                    self._ws_tasks["peer"] = None
+                    except (aiohttp.WSServerHandshakeError, ValueError) as e:
+                        self._logger.debug(
+                            "Websocket peer {0}: {1}".format(type(e).__name__, str(e))
+                        )
+                        await self.request_peers()
+                    except (ClientError, gaierror, TimeoutError) as e:
+                        self._logger.debug(
+                            "{:}:{:}".format(str(e.__class__.__name__), str(e))
+                        )
+                        self.handle_failure()
+                    except jsonschema.ValidationError as e:
+                        self._logger.debug(
+                            "{:}:{:}".format(str(e.__class__.__name__), str(e))
+                        )
+                        self.handle_failure(weight=3)
+                    except RuntimeError as e:
+                        self._logger.error(str(e))
+                    except AttributeError as e:
+                        if "feed_appdata" in str(e) or "do_handshake" in str(e):
+                            self._logger.debug(str(e))
+                        else:
+                            raise
+                    finally:
+                        self._connected["peer"] = False
+                        self._ws_tasks["peer"] = None
 
     async def request_peers(self):
         """
         Refresh the list of peers knew by this node
         """
+        found_peer_data = False
         for endpoint in [e for e in self.node.endpoints if isinstance(e, BMAEndpoint)]:
             try:
                 peers_data = await self.safe_request(
@@ -354,8 +341,9 @@ class NodeConnector(QObject):
                             if not leaf_data:
                                 break
                             self.refresh_peer_data(leaf_data["leaf"]["value"])
+                            found_peer_data = True
                         except (AttributeError, ValueError) as e:
-                            if ("feed_appdata", "do_handshake") in str(e):
+                            if "feed_appdata" in str(e) or "do_handshake" in str(e):
                                 self._logger.debug(str(e))
                             else:
                                 self._logger.debug(
@@ -386,9 +374,7 @@ class NodeConnector(QObject):
                 self._logger.debug("Error in peers reply: {0}".format(str(e)))
                 self.handle_failure()
         else:
-            if self.session.closed:
-                pass
-            else:
+            if not found_peer_data:
                 self._logger.debug("Could not connect to any BMA endpoint")
                 self.handle_failure()
 
@@ -428,11 +414,8 @@ class NodeConnector(QObject):
                 self._logger.debug("Error in peers reply: {0}".format(str(e)))
                 self.handle_failure()
         else:
-            if self.session.closed:
-                pass
-            else:
-                self._logger.debug("Could not connect to any BMA endpoint")
-                self.handle_failure()
+            self._logger.debug("Could not connect to any BMA endpoint")
+            self.handle_failure()
 
     def handle_success(self):
         self.success.emit()
