@@ -1,9 +1,6 @@
 import attr
 import sqlite3
 
-from duniterpy.documents.ws2p.heads import HeadV2
-
-from sakia.constants import ROOT_SERVERS
 from ..entities import Node
 from duniterpy.documents import BlockUID
 import logging
@@ -14,17 +11,13 @@ import time
 class NodesProcessor:
     _repo = attr.ib()  # :type sakia.data.repositories.NodesRepo
 
-    @classmethod
-    def instanciate(cls, app):
-        return cls(app.db.nodes_repo)
-
-    def initialize_root_nodes(self, currency):
+    def initialize_root_nodes(self, currency, root_servers):
         if not self.nodes(currency):
-            for pubkey in ROOT_SERVERS[currency]["nodes"]:
+            for pubkey in root_servers[currency]["nodes"]:
                 node = Node(
                     currency=currency,
                     pubkey=pubkey,
-                    endpoints=ROOT_SERVERS[currency]["nodes"][pubkey],
+                    endpoints=root_servers[currency]["nodes"][pubkey],
                     peer_blockstamp=BlockUID.empty(),
                     state=0,
                 )
@@ -187,9 +180,3 @@ class NodesProcessor:
             node.last_state_change = time.time()
         node.state = min(5, node.state + weight)
         self.update_node(node)
-
-    def drop_all(self, currency):
-        nodes = self._repo.get_all()
-        for n in nodes:
-            if n.pubkey not in ROOT_SERVERS[currency].keys():
-                self._repo.drop(n)
