@@ -5,8 +5,7 @@ from ..entities import Transaction, Dividend
 
 @attr.s(frozen=True)
 class TransactionsRepo:
-    """The repository for Communities entities.
-    """
+    """The repository for Communities entities."""
 
     _conn = attr.ib()  # :type sqlite3.Connection
     _primary_keys = (
