@@ -71,7 +71,7 @@ class ConnectionConfigController(QObject):
         :return: a new AccountConfigController controller
         :rtype: AccountConfigController
         """
-        view = ConnectionConfigView(parent.view if parent else None)
+        view = ConnectionConfigView(parent.view if parent else None, app)
         model = ConnectionConfigModel(
             None, app, None, IdentitiesProcessor.instanciate(app)
         )
