@@ -40,7 +40,9 @@ class NetworkController(QObject):
         :param sakia.services.NetworkService network_service:
         :return:
         """
-        view = NetworkView(parent.view,)
+        view = NetworkView(
+            parent.view,
+        )
         model = NetworkModel(None, app, network_service)
         txhistory = cls(parent, view, model)
         model.setParent(txhistory)
