@@ -52,7 +52,9 @@ class TransferController(QObject):
             self.change_current_connection
         )
         self.view.spinbox_amount.valueChanged.connect(self.handle_amount_change)
-        self.view.spinbox_relative.valueChanged.connect(self.handle_relative_change)
+        self.view.spinbox_referential.valueChanged.connect(
+            self.handle_referential_change
+        )
         self.view.button_source_check.clicked.connect(self.check_source_dialog)
 
     @classmethod
@@ -78,6 +80,10 @@ class TransferController(QObject):
         controller = cls(view, model, search_user, user_information, password_input)
 
         search_user.identity_selected.connect(user_information.search_identity)
+        app.referential_changed.connect(controller.refresh)
+        controller.view.label_referential_units.setText(
+            app.current_ref.instance(0, app.currency, app, None).diff_units
+        )
 
         view.set_keys(controller.model.available_connections())
         view.set_contacts(controller.model.contacts())
@@ -116,7 +122,7 @@ class TransferController(QObject):
             )
             controller.set_amount_value(source.amount, source.base)
             controller.view.spinbox_amount.setDisabled(True)
-            controller.view.spinbox_relative.setDisabled(True)
+            controller.view.spinbox_referential.setDisabled(True)
             result, _ = controller.check_source(source)
             # by default, source is unlocked, if not...
             if not result:
@@ -293,6 +299,19 @@ class TransferController(QObject):
         current_base_amount = amount / pow(10, current_base)
         total_text = self.model.localized_amount(amount)
         self.view.refresh_labels(total_text)
+        self.view.label_referential_units.setText(
+            self.model.app.current_ref.instance(
+                amount, self.model.app.currency, self.model.app, None
+            ).diff_units
+        )
+
+        # if referential = units, then hide useless referential spinbox
+        if self.model.app.current_ref == Quantitative:
+            self.view.spinbox_referential.hide()
+            self.view.label_referential_units.hide()
+        else:
+            self.view.spinbox_referential.show()
+            self.view.label_referential_units.show()
 
         if amount == 0:
             self.view.set_button_box(TransferView.ButtonBoxState.NO_AMOUNT)
@@ -310,19 +329,23 @@ class TransferController(QObject):
         if self.model.current_source and self.view.button_source_check.isEnabled():
             self.view.set_button_box(TransferView.ButtonBoxState.SOURCE_LOCKED)
 
-        max_relative = self.model.quant_to_rel(current_base_amount / 100)
+        max_relative = self.model.quantitative_to_referential(amount / 100)
         self.view.spinbox_amount.setSuffix(Quantitative.base_str(current_base))
 
         self.view.set_spinboxes_parameters(current_base_amount / 100, max_relative)
 
     def handle_amount_change(self, value):
-        relative = self.model.quant_to_rel(value)
-        self.view.change_relative_amount(relative)
+        current_base = self.model.current_base()
+        current_base_value = value / pow(10, current_base)
+        referential_amount = self.model.quantitative_to_referential(current_base_value)
+        self.view.change_referential_amount(referential_amount)
         self.refresh()
 
-    def handle_relative_change(self, value):
-        amount = self.model.rel_to_quant(value)
-        self.view.change_quantitative_amount(amount)
+    def handle_referential_change(self, value):
+        amount = self.model.referential_to_quantitative(value)
+        current_base = self.model.current_base()
+        current_base_amount = amount / 100 / pow(10, current_base)
+        self.view.change_quantitative_amount(current_base_amount)
         self.refresh()
 
     def change_current_connection(self, index):
@@ -408,16 +431,17 @@ class TransferController(QObject):
 
     def set_amount_value(self, amount, base):
         """
-        Set quantitative and relative amounts from amount and base given
+        Set quantitative and referential amounts from amount and base given
         :param int amount: Amount to display
         :param int base: Base of the amount given
         :return:
         """
-        # calculate amount for current base
+        # calculate value (from money cents) for current base
         current_base = self.model.current_base()
-        current_base_amount = amount / pow(10, base - current_base)
-        # display quantitative and relative amounts
-        relative = self.model.quant_to_rel(current_base_amount / 100)
-        self.view.set_spinboxes_parameters(current_base_amount / 100, relative)
-        self.view.change_relative_amount(relative)
-        self.view.change_quantitative_amount(current_base_amount / 100)
+        current_base_value = amount / pow(10, base - current_base) / 100
+
+        # display quantitative and referential amounts
+        referential_amount = self.model.quantitative_to_referential(current_base_value)
+        self.view.set_spinboxes_parameters(current_base_value, referential_amount)
+        self.view.change_referential_amount(referential_amount)
+        self.view.change_quantitative_amount(current_base_value)
