@@ -421,7 +421,9 @@ class DocumentsService:
                     SIG.token(receiver),
                     Operator.token("||"),
                     Condition.token(
-                        SIG.token(issuer), Operator.token("&&"), CSV.token(604800),
+                        SIG.token(issuer),
+                        Operator.token("&&"),
+                        CSV.token(604800),
                     ),
                 ),
                 Condition,
