@@ -239,7 +239,11 @@ class TransactionsService(QObject):
                 pubkey, tx_doc.sha_hash
             ) and SimpleTransaction.is_simple(tx_doc):
                 tx = parse_transaction_doc(
-                    tx_doc, pubkey, tx_data["block_number"], tx_data["time"], txid,
+                    tx_doc,
+                    pubkey,
+                    tx_data["block_number"],
+                    tx_data["time"],
+                    txid,
                 )
                 if tx:
                     new_transfers.append(tx)
